Struct

GumImportDetails

Description [src]

struct GumImportDetails {
  GumImportType type;
  const gchar* name;
  const gchar* module;
  GumAddress address;
  GumAddress slot;
}

Details about an imported symbol, as passed to a GumFoundImportFunc.

Structure members
type: GumImportType

The kind of import.

name: const gchar*

Name of the imported symbol.

module: const gchar*

Name of the module it is imported from, if known.

address: GumAddress

Resolved address of the import, or 0 if not resolved.

slot: GumAddress

Address of the slot holding the import, or 0 if not applicable.