Struct
GumImportDetails
Description [src]
struct GumImportDetails {
GumImportType type;
const gchar* name;
const gchar* module;
GumAddress address;
GumAddress slot;
}
Details about an imported symbol, as passed to a GumFoundImportFunc.
Structure members
type:GumImportTypeThe kind of import.
name:const gchar*Name of the imported symbol.
module:const gchar*Name of the module it is imported from, if known.
address:GumAddressResolved address of the import, or 0 if not resolved.
slot:GumAddressAddress of the slot holding the import, or 0 if not applicable.